==> libnaji-0.3.0.src.tar.gz: libnaji-0.3.0.src/najicat.c <==
/* --------- */
/* najicat.c */
/* --------- */

/* naji standard output (usually screen) functions */

/* this  .c  file is a part */
/* of libnaji version 0.3.0 */

/* libnaji is based on   */
/* the original najitool */

/* both najitool and libnaji */
/* are public domain and are */
/* made by the same author   */
/* please read license.txt   */

/* made by NECDET COKYAZICI  */

#include "libnaji.h"

void naji_license(void)
{
printf("\nTHIS PROGRAM IS NON-COPYRIGHTED PUBLIC DOMAIN AND DISTRIBUTED IN THE\n");
printf("HOPE THAT IT WILL BE USEFUL BUT THERE IS NO WARRANTY FOR THE PROGRAM,\n");
printf("THE PROGRAM IS PROVIDED \"AS IS\" WITHOUT WARRANTY OF ANY KIND, EITHER\n");
printf("EXPRESSED  OR  IMPLIED, INCLUDING, BUT  NOT  LIMITED TO, THE IMPLIED\n");
printf("WARRANTIES  OF  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.\n");
printf("THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM  IS\n");
printf("WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF\n");
printf("ALL NECESSARY SERVICING, REPAIR OR CORRECTION.\n\n");
return;
}

void kitten(char *namein)
{
int a=0;

najin(namein);

    loop
    {
    a = fgetc(naji_input);
    if (a == EOF) endloop;
    fputc(a, stdout);
    }

najinclose();
}

void cat_text(char *namein)
{
int a=0;

najin(namein);

    loop
    {
    a = fgetc(naji_input);
    if (a == EOF) endloop;
    if ( ( (a > 31) && (a < 127) ) ||
         ( (a == '\n') ) ||
         ( (a == '\r') ) ||
         ( (a == '\t') )
        )
    
    
    fputc(a, stdout);
    }

najinclose();
}

/* this is better for unix because you don't really need \r on unix do you :) */
void cat_text_faster(char *namein)
{
int a=0;

najin(namein);

    loop
    {
    a = fgetc(naji_input);
    if (a == EOF) endloop;
    if ( ( (a > 31) && (a < 127) ) ||
         ( (a == '\n') ) ||
         ( (a == '\t') )
        )
    
    
    fputc(a, stdout);
    }

najinclose();
}

/* this is the fastest but doesn't include newlines or tabs */
/* because the ascii people didn't do them close by >:( */
void cat_text_fastest(char *namein)
{
int a=0;

najin(namein);

    loop
    {
    a = fgetc(naji_input);
    if (a == EOF) endloop;
    if ( ( (a > 31) && (a < 127) ) )
    fputc(a, stdout);
    }

najinclose();
}

void repcat(char *namein, unsigned int repeat)
{
int a=0;
unsigned int i=0;

najin(namein);

repeat++;

    loop
    {
    a = fgetc(naji_input);

    if (a == EOF)
    endloop;

    for (i=0; i<repeat; i++)
    fputc(a, stdout);
    }

najinclose();
}

void repcatpp(char *namein, unsigned int start)
{
int a=0;
unsigned int i=0;

najin(namein);

start++;

    loop
    {
    a = fgetc(naji_input);

    if (a == EOF)
    endloop;

    for (i=0; i<start; i++)
    fputc(a, stdout);

    start++;
    }

najinclose();
}



void skipcat(char *namein, char *toskip)
{
int skip = NAJI_FALSE;
int a=0;
int i=0;
int l=0;

    l = strlen(toskip);

najin(namein);

    loop
    {
    a = fgetc(naji_input);
    if (a == EOF) endloop;
    skip = NAJI_FALSE;

    for (i=0; i<l; i++)
    if (a == toskip[i])
    skip = NAJI_TRUE;

    if (skip == NAJI_FALSE)
    fputc(a, stdout);
    }

najinclose();
}

void onlycat(char *namein, char *toshow)
{
int show = NAJI_TRUE;
int a=0;
int i=0;
int l=0;


najin(namein);

    l = strlen(toshow);

        loop
        {
        a = fgetc(naji_input);
        if (a == EOF) endloop;

        show = NAJI_FALSE;

        for (i=0; i<l; i++)
        if (a == toshow[i])
        show = NAJI_TRUE;

        if (show == NAJI_TRUE)
        fputc(a, stdout);
        }

najinclose();
}


void rndbsout(unsigned long int size)
{
unsigned long int i=0;

srand(time(NULL));
for (i=0; i<size; i++)
fputc((rand() % 255), stdout);
}


void rndtsout(unsigned long int size)
{
unsigned long int i=0;

srand(time(NULL));
for (i=0; i<size; i++)
fputc(((rand() % 95)+' '), stdout);
}


void hexicat(char *namein)
{
int offset=0;
int a;
int i;
int ii;
int x;

    najin(namein);

    a = fgetc(naji_input);

    loop
    {
    
        if (a == EOF) endloop;
    
        printf("%08X: ", offset);

        for (ii=0; ii<4; ii++)
        {
            for (i=0; i<4; i++)
            {
            a = fgetc(naji_input);
            offset++; 
            if (a != EOF) printf(" %02X", a);
            }

        fputc(' ', stdout);
        }

    fseek(naji_input, (-16), SEEK_CUR);

    for (x=0; x<16; x++)
    {
    a = fgetc(naji_input);

    if ( (a >= ' ') && (a <= '~') )
    fputc(a, stdout);
    else if (a == EOF) endloop;
    else fputc('.', stdout);
    }

    fputc('\n', stdout);
    fseek(naji_input, (+16), SEEK_CUR);
    }

najinclose();
}




void coffset(char *namein, long startpos, long endpos)
{
long filesize=0;
long i;

najin(namein);

filesize=najinsize();


  if (startpos > endpos)
  {
  fprintf(stderr,
  "Error, start position cannot be greater than end possition.\n\n");
  exit(15);
  }

  if (startpos > filesize)
  {
  fprintf(stderr,
  "Error, start position is greater than the file size.\n\n");
  exit(16);
  }

  if (endpos > filesize)
  {
  fprintf(stderr,
  "Error, end position is greater than the file size.\n\n");
  exit(17);
  }


  fseek(naji_input, startpos, SEEK_SET);

  for (i=startpos; i<endpos; i++)
  fputc(fgetc(naji_input), stdout);


najinclose();
}


void revcat(char *namein)
{
int a=0;
long pos;

najin(namein);

    pos = najinsize();

    loop
    {
    pos--;
    if (pos < 0) endloop;

    fseek(naji_input, pos, SEEK_SET);

    a = fgetc(naji_input);
    fputc(a, stdout);
    }

najinclose();
}

==> libnaji-0.4.0.src.tar.gz: libnaji-0.4.0.src/najicat.c <==
/* --------- */
/* najicat.c */
/* --------- */

/* naji standard output (usually screen) functions */

/* this  .c  file is a part */
/* of libnaji version 0.4.0 */

/* libnaji is based on   */
/* the original najitool */

/* both najitool and libnaji */
/* are public domain and are */
/* made by the same author   */
/* please read license.txt   */

/* made by NECDET COKYAZICI  */

#include "libnaji.h"

void naji_license(void)
{
printf("\nTHIS PROGRAM IS NON-COPYRIGHTED PUBLIC DOMAIN AND DISTRIBUTED IN THE\n");
printf("HOPE THAT IT WILL BE USEFUL BUT THERE IS NO WARRANTY FOR THE PROGRAM,\n");
printf("THE PROGRAM IS PROVIDED \"AS IS\" WITHOUT WARRANTY OF ANY KIND, EITHER\n");
printf("EXPRESSED  OR  IMPLIED, INCLUDING, BUT  NOT  LIMITED TO, THE IMPLIED\n");
printf("WARRANTIES  OF  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.\n");
printf("THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM  IS\n");
printf("WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF\n");
printf("ALL NECESSARY SERVICING, REPAIR OR CORRECTION.\n\n");
return;
}

void kitten(char *namein)
{
int a=0;

najin(namein);

    loop
    {
    a = fgetc(naji_input);
    if (a == EOF) endloop;
    fputc(a, stdout);
    }

najinclose();
}

void cat_text(char *namein)
{
int a=0;

najin(namein);

    loop
    {
    a = fgetc(naji_input);
    if (a == EOF) endloop;
    if ( ( (a > 31) && (a < 127) ) ||
         ( (a == '\n') ) ||
         ( (a == '\r') ) ||
         ( (a == '\t') )
        )
    
    
    fputc(a, stdout);
    }

najinclose();
}

/* this is better for unix because you don't really need \r on unix do you */
void cat_text_faster(char *namein)
{
int a=0;

najin(namein);

    loop
    {
    a = fgetc(naji_input);
    if (a == EOF) endloop;
    if ( ( (a > 31) && (a < 127) ) ||
         ( (a == '\n') ) ||
         ( (a == '\t') )
        )
    
    
    fputc(a, stdout);
    }

najinclose();
}

/* this is the fastest but doesn't include newlines or tabs */
/* because the ascii people didn't do them close by */
void cat_text_fastest(char *namein)
{
int a=0;

najin(namein);

    loop
    {
    a = fgetc(naji_input);
    if (a == EOF) endloop;
    if ( ( (a > 31) && (a < 127) ) )
    fputc(a, stdout);
    }

najinclose();
}

void repcat(char *namein, unsigned int repeat)
{
int a=0;
unsigned int i=0;

najin(namein);

repeat++;

    loop
    {
    a = fgetc(naji_input);

    if (a == EOF)
    endloop;

    for (i=0; i<repeat; i++)
    fputc(a, stdout);
    }

najinclose();
}

void repcatpp(char *namein, unsigned int start)
{
int a=0;
unsigned int i=0;

najin(namein);

start++;

    loop
    {
    a = fgetc(naji_input);

    if (a == EOF)
    endloop;

    for (i=0; i<start; i++)
    fputc(a, stdout);

    start++;
    }

najinclose();
}



void skipcat(char *namein, char *toskip)
{
int skip = NAJI_FALSE;
int a=0;
int i=0;
int l=0;

    l = strlen(toskip);

najin(namein);

    loop
    {
    a = fgetc(naji_input);
    if (a == EOF) endloop;
    skip = NAJI_FALSE;

    for (i=0; i<l; i++)
    if (a == toskip[i])
    skip = NAJI_TRUE;

    if (skip == NAJI_FALSE)
    fputc(a, stdout);
    }

najinclose();
}

void onlycat(char *namein, char *toshow)
{
int show = NAJI_TRUE;
int a=0;
int i=0;
int l=0;


najin(namein);

    l = strlen(toshow);

        loop
        {
        a = fgetc(naji_input);
        if (a == EOF) endloop;

        show = NAJI_FALSE;

        for (i=0; i<l; i++)
        if (a == toshow[i])
        show = NAJI_TRUE;

        if (show == NAJI_TRUE)
        fputc(a, stdout);
        }

najinclose();
}


void rndbsout(unsigned long int size)
{
unsigned long int i=0;

srand(time(NULL));
for (i=0; i<size; i++)
fputc((rand() % 255), stdout);
}


void rndtsout(unsigned long int size)
{
unsigned long int i=0;

srand(time(NULL));
for (i=0; i<size; i++)
fputc(((rand() % 95)+' '), stdout);
}


void hexicat(char *namein)
{
int offset=0;
int a;
int i;
int ii;
int x;

    najin(namein);

    a = fgetc(naji_input);

    loop
    {
    
        if (a == EOF) endloop;
    
        printf("%08X: ", offset);

        for (ii=0; ii<4; ii++)
        {
            for (i=0; i<4; i++)
            {
            a = fgetc(naji_input);
            offset++; 
            if (a != EOF) printf(" %02X", a);
            }

        fputc(' ', stdout);
        }

    fseek(naji_input, (-16), SEEK_CUR);

    for (x=0; x<16; x++)
    {
    a = fgetc(naji_input);

    if ( (a >= ' ') && (a <= '~') )
    fputc(a, stdout);
    else if (a == EOF) endloop;
    else fputc('.', stdout);
    }

    fputc('\n', stdout);
    fseek(naji_input, (+16), SEEK_CUR);
    }

najinclose();
}




void coffset(char *namein, long startpos, long endpos)
{
long filesize=0;
long i;

najin(namein);

filesize=najinsize();


  if (startpos > endpos)
  {
  fprintf(stderr,
  "Error, start position cannot be greater than end possition.\n\n");
  exit(15);
  }

  if (startpos > filesize)
  {
  fprintf(stderr,
  "Error, start position is greater than the file size.\n\n");
  exit(16);
  }

  if (endpos > filesize)
  {
  fprintf(stderr,
  "Error, end position is greater than the file size.\n\n");
  exit(17);
  }


  fseek(naji_input, startpos, SEEK_SET);

  for (i=startpos; i<endpos; i++)
  fputc(fgetc(naji_input), stdout);


najinclose();
}



void dumpoffs(char *namein, long startpos, long endpos)
{
long filesize=0;
long i;

najin(namein);

filesize=najinsize();


  if (startpos > endpos)
  {
  fprintf(stderr,
  "Error, start position cannot be greater than end possition.\n\n");
  exit(15);
  }

  if (startpos > filesize)
  {
  fprintf(stderr,
  "Error, start position is greater than the file size.\n\n");
  exit(16);
  }

  if (endpos > filesize)
  {
  fprintf(stderr,
  "Error, end position is greater than the file size.\n\n");
  exit(17);
  }


  fseek(naji_input, startpos, SEEK_SET);

  for (i=startpos; i<endpos; i++)
  printf("%02X ", fgetc(naji_input));

najinclose();
}


void revcat(char *namein)
{
int a=0;
long pos;

najin(namein);

    pos = najinsize();

    loop
    {
    pos--;
    if (pos < 0) endloop;

    fseek(naji_input, pos, SEEK_SET);

    a = fgetc(naji_input);
    fputc(a, stdout);
    }

najinclose();
}

void naji_credits(void)
{
printf("\n");
printf("  =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-\n");
printf("  najitool 0.6.0 and libnaji 0.4.0 Credits\n");
printf("  =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-\n");
printf("  in order of joining the project najitool\n");
printf("\n");
printf("NECDET COKYAZICI - England, London - cokyazici@yahoo.co.uk\n");
printf("Main author, programmer, tester, debugger, and project manager.\n");
printf("Wrote everything that someone else didn't write.\n");
printf("\n");
printf("SELCUK OZDOGAN - Turkey, Istanbul - selcuk198@yahoo.com\n");
printf("Programmer. Wrote charbefr, charaftr.\n");
printf("\n");
printf("POLIKARP - Poland - polikarp@users.sourceforge.net\n");
printf("Programmer. Wrote strbline, streline, chchar.\n");
printf("\n");
printf("SAMUEL CHANG - Australia - badp1ayer@hotmail.com\n");
printf("Programmer. Wrote the fun Tic-Tac-Toe game with clever AI.\n");
printf("\n");
}
